#!/bin/sh
# COPYRIGHT (C) HITACHI,LTD. 2003-2004
# Written by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>

LKSTMAJ=`cat /proc/devices | grep lkst | cut -f 1 -d " "`
if [ -z "$LKSTMAJ" ] ; then 
echo "Error: Run after enabled lkst."
exit 0
fi
[ -c /dev/lkst ] && rm -f /dev/lkst
/bin/mknod -m 0600 /dev/lkst c $LKSTMAJ 0
i=0
while [ $i -le 31 ]; do
[ -c /dev/lkst$i ] && rm -f /dev/lkst$i
/bin/mknod -m 0600 /dev/lkst$i c $LKSTMAJ `expr $i + 1`
i=`expr $i + 1`
done
